==> open-xchange-calendar-printing_7.6.3.orig.tar.bz2: open-xchange-calendar-printing-7.6.3/com.openexchange.calendar.printing/src/com/openexchange/calendar/printing/templating/CalendarHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.calendar.printing.templating;

import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;
import com.openexchange.server.ServiceLookup;


/**
 * {@link CalendarHelper}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class CalendarHelper {

    private final CalendarFormatter formatters;
    private final EnhancedAppointment enhanced;
    private final CalendarLabels labels;

    /**
     * Initializes a new {@link CalendarHelper}.
     * @param resultObject
     * @throws OXException 
     */
    public CalendarHelper(Map<String, Object> appointment, Locale locale, TimeZone timezone, Context ctx, ServiceLookup services) throws OXException {
        super();
        this.formatters = new CalendarFormatter(appointment, locale, timezone);
        this.enhanced = new EnhancedAppointment(appointment, services, ctx);
        this.labels = new CalendarLabels(appointment, locale, services);
    }

    
    public CalendarFormatter getFormatters() {
        return formatters;
    }

    
    public EnhancedAppointment getEnhanced() {
        return enhanced;
    }

    
    public CalendarLabels getLabels() {
        return labels;
    }
    
    
    
}

==> open-xchange-calendar-printing_7.10.1.orig.tar.bz2: open-xchange-calendar-printing-7.10.1/com.openexchange.calendar.printing/src/com/openexchange/calendar/printing/templating/CalendarHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.calendar.printing.templating;

import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;
import com.openexchange.server.ServiceLookup;


/**
 * {@link CalendarHelper}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class CalendarHelper {

    private final CalendarFormatter formatters;
    private final EnhancedEvent enhanced;
    private final CalendarLabels labels;

    /**
     * Initializes a new {@link CalendarHelper}.
     * @param resultObject
     * @throws OXException 
     */
    public CalendarHelper(Map<String, Object> appointment, Locale locale, TimeZone timezone, Context ctx, ServiceLookup services) throws OXException {
        super();
        this.formatters = new CalendarFormatter(appointment, locale, timezone);
        this.enhanced = new EnhancedEvent(appointment, services, ctx);
        this.labels = new CalendarLabels(appointment, locale, services);
    }

    
    public CalendarFormatter getFormatters() {
        return formatters;
    }

    
    public EnhancedEvent getEnhanced() {
        return enhanced;
    }

    
    public CalendarLabels getLabels() {
        return labels;
    }
}
